@@ -87,11 +87,11 @@ class mysqlUtil:
     def get_file_list(self, ftype):
         if ftype:
             ftype = str(ftype).lower()
-            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
+            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
                 ftype)
         else:
             ftype = ".mp4"
-            'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
+            'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
                 ftype)
         df = pd.read_sql(sql, self.engine)
         results = json.loads(df.to_json(orient='records'))
@@ -106,11 +106,11 @@ class mysqlUtil:
     def get_files_bypid(self, pid):
         if pid:
             pid = str(pid).upper()
-            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where pid="{}" order by uptime desc limit 100'.format(
+            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         else:
-            pid = "P023101"
-            'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where pid="{}" order by uptime desc limit 100'.format(
+            pid = "p023101"
+            'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         df = pd.read_sql(sql, self.engine)
         results = json.loads(df.to_json(orient='records'))
